@@ -135,8 +135,8 @@ class SourceDevice:
 
         error = []
         if self.ip.rsplit('.', 1)[1] == ip_info[self.device_name] \
-                and self.netmask == ip_info['netmask'] \
-                and self.gateway.rsplit('.', 1)[1] == ip_info['gw']:
+           and self.netmask == ip_info['netmask'] \
+           and self.gateway.rsplit('.', 1)[1] == ip_info['gw']:
             return
         if self.ip.rsplit('.', 1)[1] != ip_info[self.device_name]:
             error.append(f'{self.hostname} ' +
@@ -147,7 +147,6 @@ class SourceDevice:
         if self.gateway.rsplit('.', 1)[1] != ip_info['gw']:
             error.append(f'{self.hostname} ' +
                         error_codes[3] + '\nCurrent: {}'.format(self.gateway))
-
         return error
 
 
@@ -250,11 +249,11 @@ class ReferenceInformation:
                 continue
             if all(substring in line for substring in ['<IP>', '<SUBNET>']):
                 unique_source_list.append(
-                    line.replace('<IP>', source_device.net_info['ip']).replace('<SUBNET>', source_device.net_info['netmask']))
+                    line.replace('<IP>', source_device.ip).replace('<SUBNET>', source_device.netmask))
                 continue
             if '<GATEWAY>' in line:
                 unique_source_list.append(line.replace(
-                    '<GATEWAY>', source_device.net_info['gateway']))
+                    '<GATEWAY>', source_device.gateway))
                 continue
             unique_source_list.append(line)
 
